#!/bin/bash
#       build-armagetronad.sh
#
#       Copyright 2011 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

name=armagetronad
version=0.2.8.3.1
arch=i686
cpu=i686
build=72.1

working_dir=$PWD

extra_docs=(
  AUTHORS
  COPYING
  ChangeLog
  INSTALL
  NEWS
  README
  README-DEVELOPER
  README-KDevelop3_0
  README-SDL
  src/doc/Content_Creation/Howto-Maps.txt
)

#the icons
icons=(
  [48]=large
  [32]=medium
  [16]=small
)

#directories which should be removed on exit
created_dirs=()
trap 'rm -rf "${created_dirs[@]}"' EXIT

#the temporary directory
tmpdir=/tmp/$name.$RANDOM$$$RANDOM
created_dirs=$tmpdir
mkdir "$tmpdir" || exit 1

created_dirs+=( .bin )

#execute ./configure
#libpng 1.4 doesnot work, we need libpng 1.2, since i couldn't find  way to make
#configure use libpng12-config instead of libpng-config, we use the following hack

mkdir .bin || exit 1
ln -s /usr/bin/libpng12-config .bin/libpng-config

PATH=".bin/:$PATH" \
CFLAGS="-O2 -march=$arch -mtune=$cpu" \
CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \
./configure --prefix=/usr \
            --docdir=/usr/doc \
            --sysconfdir=/etc \
            --disable-games \
            --disable-etc \
            --disable-uninstall \
            --enable-music

make || exit 1

make install-strip "DESTDIR=$tmpdir"

cd "$tmpdir" || exit 1

#the .desktop file
mkdir -p usr/share/applications
( cd "$_" && ln -sf ../armagetronad/desktop/armagetronad.desktop armagetronad.desktop )

#the icons
for i in "${!icons[@]}" ;do

  mkdir -p usr/share/icons/hicolor/"$i"x"$i"/apps

  (
    cd "$_" &&
    ln -sf \
      ../../../../armagetronad/desktop/icons/"${icons[i]}"/armagetronad.png \
      armagetronad.png
  )

done

#documentation directory doesnot have a version number
mv usr/doc/armagetronad usr/doc/"$name-$version"

#copy other docs from working directory
cp "${extra_docs[@]/#/$working_dir/}" usr/doc/"$name-$version"

#add build file
mkdir -p usr/src/"$name-$version"
cp "$working_dir/build-$name.sh" "$_"

#create slack-desc
mkdir -p install

# Create the slack-desc file
cat > install/slack-desc <<SLACK-DESC
$name: armagetronad is a 3d light cycle game
$name:
$name: Armagetron is a multiplayer game in 3d that attempts to emulate and
$name: expand on the lightcycle sequence from the movie Tron.
$name:
$name:
$name:
$name:
$name:
$name:
$name:
SLACK-DESC

makepkg -l y -c y "$working_dir/$name-$version-$arch-$build.txz"
